==> quality_report-1.80.3.tar.gz: quality_report-1.80.3/hqlib/domain/__init__.py <==
"""
Copyright 2012-2017 Ministerie van Sociale Zaken en Werkgelegenheid

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


# Package for domain objects.

from .base import DomainObject

from .measurement.metric import Metric
from .measurement.directed_metric import HigherIsBetterMetric, LowerIsBetterMetric
from .measurement.percentage_metric import PercentageMetric, HigherPercentageIsBetterMetric, \
    LowerPercentageIsBetterMetric
from .measurement.metric_source_age_metric import MetricSourceAgeMetric
from .measurement.metric_source import MetricSource, MissingMetricSource
from .measurement.target import TechnicalDebtTarget, DynamicTechnicalDebtTarget

from .software_development.product import Product, Component, Application
from .software_development.team import Team
from .software_development.person import Person
from .software_development.project import Project
from .software_development.requirement import Requirement, RequirementSubject
from .software_development.document import Document
from .software_development.environment import Environment

==> quality_report-2.46.2.tar.gz: quality_report-2.46.2/hqlib/domain/__init__.py <==
"""
Copyright 2012-2018 Ministerie van Sociale Zaken en Werkgelegenheid

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


# Package for domain objects.

from .base import DomainObject

from .measurement.metric import Metric, ExtraInfo
from .measurement.directed_metric import HigherIsBetterMetric, LowerIsBetterMetric
from .measurement.percentage_metric import PercentageMetric, HigherPercentageIsBetterMetric, \
    LowerPercentageIsBetterMetric
from .measurement.metric_source_age_metric import MetricSourceAgeMetric
from .measurement.metric_source import MetricSource
from .measurement.target import AdaptedTarget, TechnicalDebtTarget, DynamicTechnicalDebtTarget

from .software_development.product import Product, Component, Application
from .software_development.team import Team
from .software_development.person import Person
from .software_development.process import Process, ProjectManagement, IssueManagement, Scrum
from .software_development.project import Project
from .software_development.requirement import Requirement, RequirementSubject
from .software_development.document import Document
from .software_development.environment import Environment
